Interface EscapeCodeFactory

All Superinterfaces:
LookupFactory<String,Object>
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface EscapeCodeFactory extends LookupFactory<String,Object>
A LookupFactory for creating ANSI Escape-Codes from an instance of a given type.