- java.lang.Object
-
- java.lang.Enum<RandomTextMode>
-
- org.refcodes.textual.RandomTextMode
-
- All Implemented Interfaces:
Serializable,Comparable<RandomTextMode>,org.refcodes.mixin.CharSetAccessor
public enum RandomTextMode extends Enum<RandomTextMode> implements org.refcodes.mixin.CharSetAccessor
TheRandomTextModespecifies for according chars to be used when generating random text.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.CharSetAccessor
org.refcodes.mixin.CharSetAccessor.CharSetBuilder<B extends org.refcodes.mixin.CharSetAccessor.CharSetBuilder<B>>, org.refcodes.mixin.CharSetAccessor.CharSetMutator, org.refcodes.mixin.CharSetAccessor.CharSetProperty
-
-
Enum Constant Summary
Enum Constants Enum Constant Description ALPHABETICRepresents a charset consisting of only upper and lower case letters.ALPHANUMERICRepresents a charset consisting of only upper and lower case characters as well as of the digits 0 to 9.ASCIIRepresents a charset consisting of only ASCII characters.BINARYRepresents a charset consisting of only digits 0 and 1.HEXADECIMALRepresents a charset consisting of only digits 0 to 9 as well as the characters A to F.LOWER_CASERepresents a charset consisting of only lower case letters.LOWER_CASE_ALPHANUMERICRepresents a charset consisting of only lower case characters as well as of the digits 0 to 9.NUMERICRepresents a charset consisting of only digits 0 to 9.UPPER_CASERepresents a charset consisting of only upper case letters.UPPER_CASE_ALPHANUMERICRepresents a charset consisting of only upper case characters as well as of the digits 0 to 9.
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description char[]getCharSet()static RandomTextModevalueOf(String name)Returns the enum constant of this type with the specified name.static RandomTextMode[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
ASCII
public static final RandomTextMode ASCII
Represents a charset consisting of only ASCII characters.
-
ALPHABETIC
public static final RandomTextMode ALPHABETIC
Represents a charset consisting of only upper and lower case letters.
-
UPPER_CASE
public static final RandomTextMode UPPER_CASE
Represents a charset consisting of only upper case letters.
-
LOWER_CASE
public static final RandomTextMode LOWER_CASE
Represents a charset consisting of only lower case letters.
-
ALPHANUMERIC
public static final RandomTextMode ALPHANUMERIC
Represents a charset consisting of only upper and lower case characters as well as of the digits 0 to 9.
-
UPPER_CASE_ALPHANUMERIC
public static final RandomTextMode UPPER_CASE_ALPHANUMERIC
Represents a charset consisting of only upper case characters as well as of the digits 0 to 9.
-
LOWER_CASE_ALPHANUMERIC
public static final RandomTextMode LOWER_CASE_ALPHANUMERIC
Represents a charset consisting of only lower case characters as well as of the digits 0 to 9.
-
NUMERIC
public static final RandomTextMode NUMERIC
Represents a charset consisting of only digits 0 to 9.
-
BINARY
public static final RandomTextMode BINARY
Represents a charset consisting of only digits 0 and 1.
-
HEXADECIMAL
public static final RandomTextMode HEXADECIMAL
Represents a charset consisting of only digits 0 to 9 as well as the characters A to F.
-
-
Method Detail
-
values
public static RandomTextMode[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (RandomTextMode c : RandomTextMode.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static RandomTextMode valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getCharSet
public char[] getCharSet()
- Specified by:
getCharSetin interfaceorg.refcodes.mixin.CharSetAccessor
-
-