- All Implemented Interfaces:
Serializable,Comparable<TableStyle>,Constable
The Enum TableStyle defines character sets for various box border styles.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionSame asASCII_HEADER_ASCII_BODYas of convenience purposes.Representing a table style usingTextBoxStyle.ASCII_BLANKfor the header andTextBoxStyle.ASCII_BLANKfor the body.Representing a table style usingTextBoxStyle.ASCIIfor the header andTextBoxStyle.ASCIIfor the body.Same asBLANK_HEADER_BLANK_BODYas of convenience purposes.Representing a table style usingTextBoxStyle.BLANKfor the header andTextBoxStyle.BLANKfor the body.Same asBOLD_HEADER_BOLD_BODYas of convenience purposes.Representing a table style usingTextBoxStyle.BOLDfor the header andTextBoxStyle.BOLDfor the body.Representing a table style usingTextBoxStyle.BOLD_HEADER_SINGLE_BODYfor the header andTextBoxStyle.SINGLEfor the body.Same asDOUBLE_HEADER_DOUBLE_BODYas of convenience purposes.Representing a table style usingTextBoxStyle.DOUBLEfor the header andTextBoxStyle.DOUBLEfor the body.Representing a table style usingTextBoxStyle.DOUBLEfor the header andTextBoxStyle.DOUBLE_SINGLEfor the body.Representing a table style usingTextBoxStyle.DOUBLE_SINGLEfor the header andTextBoxStyle.DOUBLE_SINGLEfor the body.Representing a table style usingTextBoxStyle.DOUBLE_SINGLEfor the header andTextBoxStyle.SINGLEfor the body.Representing a table style usingTextBoxStyle.DOUBLE_SINGLEfor the header andTextBoxStyle.DOUBLE_SINGLEfor the body.Representing a table style usingTextBoxStyle.HYBRID_BOLD_HEADER_SINGLE_BODYfor the header andTextBoxStyle.SINGLEfor the body.Same asSINGLE_HEADER_SINGLE_BODYas of convenience purposes.Representing a table style usingTextBoxStyle.SINGLE_BLANKfor the header andTextBoxStyle.SINGLE_BLANKfor the body.Representing a table style usingTextBoxStyle.DOUBLE_SINGLEfor the header andTextBoxStyle.DOUBLE_SINGLEfor the body.Representing a table style usingTextBoxStyle.SINGLE_DOUBLEfor the header andTextBoxStyle.SINGLE_DOUBLEfor the body.Representing a table style usingTextBoxStyle.SINGLEfor the header andTextBoxStyle.SINGLEfor the body. -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final TableStyleStyle displayed for sure when being under test (e.g.static final TableStyleStyle supported Unicode capable terminals (when not being under test).static final TableStyleStyle displayed for sure when being on a Windows machine. -
Method Summary
Modifier and TypeMethodDescriptiongetBody()Returns the table body's characters.Returns the table header's characters.getTail()Returns the table tail's characters.static TableStyleDepending on the runtime environment (Windows, Linux, JUnit) we prefer different table styles as depending on the runtime environment not all characters used by the various table styles may be available.static TableStyletoTableStyle(String aValue) Retrieves aTableStyledepending on the given string, ignoring the case as well as being graceful regarding "-" and "_",static TableStyleReturns the enum constant of this class with the specified name.static TableStyle[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
SINGLE
Same asSINGLE_HEADER_SINGLE_BODYas of convenience purposes. -
SINGLE_HEADER_SINGLE_BODY
Representing a table style usingTextBoxStyle.SINGLEfor the header andTextBoxStyle.SINGLEfor the body. -
DOUBLE_SINGLE_HEADER_SINGLE_BODY
Representing a table style usingTextBoxStyle.DOUBLE_SINGLEfor the header andTextBoxStyle.SINGLEfor the body. -
DOUBLE
Same asDOUBLE_HEADER_DOUBLE_BODYas of convenience purposes. -
DOUBLE_HEADER_DOUBLE_BODY
Representing a table style usingTextBoxStyle.DOUBLEfor the header andTextBoxStyle.DOUBLEfor the body. -
DOUBLE_SINGLE_HEADER_DOUBLE_SINGLE_BODY
Representing a table style usingTextBoxStyle.DOUBLE_SINGLEfor the header andTextBoxStyle.DOUBLE_SINGLEfor the body. -
SINGLE_DOUBLE_HEADER_SINGLE_BODY
Representing a table style usingTextBoxStyle.DOUBLE_SINGLEfor the header andTextBoxStyle.DOUBLE_SINGLEfor the body. -
SINGLE_DOUBLE_HEADER_SINGLE_DOUBLE_BODY
Representing a table style usingTextBoxStyle.SINGLE_DOUBLEfor the header andTextBoxStyle.SINGLE_DOUBLEfor the body. -
DOUBLE_HEADER_DOUBLE_SINGLE_BODY
Representing a table style usingTextBoxStyle.DOUBLEfor the header andTextBoxStyle.DOUBLE_SINGLEfor the body. -
DOUBLE_SINGLE_HEADER_SINGLE_DASHED_BODY
Representing a table style usingTextBoxStyle.DOUBLE_SINGLEfor the header andTextBoxStyle.DOUBLE_SINGLEfor the body. -
BOLD
Same asBOLD_HEADER_BOLD_BODYas of convenience purposes. -
BOLD_HEADER_BOLD_BODY
Representing a table style usingTextBoxStyle.BOLDfor the header andTextBoxStyle.BOLDfor the body. -
BOLD_HEADER_SINGLE_BODY
Representing a table style usingTextBoxStyle.BOLD_HEADER_SINGLE_BODYfor the header andTextBoxStyle.SINGLEfor the body. -
HYBRID_BOLD_HEADER_SINGLE_BODY
Representing a table style usingTextBoxStyle.HYBRID_BOLD_HEADER_SINGLE_BODYfor the header andTextBoxStyle.SINGLEfor the body. -
ASCII
Same asASCII_HEADER_ASCII_BODYas of convenience purposes. -
ASCII_HEADER_ASCII_BODY
Representing a table style usingTextBoxStyle.ASCIIfor the header andTextBoxStyle.ASCIIfor the body. -
BLANK
Same asBLANK_HEADER_BLANK_BODYas of convenience purposes. -
BLANK_HEADER_BLANK_BODY
Representing a table style usingTextBoxStyle.BLANKfor the header andTextBoxStyle.BLANKfor the body. -
SINGLE_BLANK_HEADER_SINGLE_BLANK_BODY
Representing a table style usingTextBoxStyle.SINGLE_BLANKfor the header andTextBoxStyle.SINGLE_BLANKfor the body. -
ASCII_BLANK_HEADER_ASCII_BLANK_BODY
Representing a table style usingTextBoxStyle.ASCII_BLANKfor the header andTextBoxStyle.ASCII_BLANKfor the body.
-
-
Field Details
-
UNICODE_TABLE_STYLE
Style supported Unicode capable terminals (when not being under test). -
WINDOWS_TABLE_STYLE
Style displayed for sure when being on a Windows machine. -
ASCII_TABLE_STYLE
Style displayed for sure when being under test (e.g. JUnit) or in a Cp1252 or a plain "xterm".
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getHeader
Returns the table header's characters.- Returns:
- The table header characters.
-
getBody
Returns the table body's characters.- Returns:
- The table body characters.
-
getTail
Returns the table tail's characters.- Returns:
- The table header characters.
-
toTableStyle
Retrieves aTableStyledepending on the given string, ignoring the case as well as being graceful regarding "-" and "_",- Parameters:
aValue- The name of theTableStyleto be interpreted graceful.- Returns:
- The
TableStylebeing determined or null if none was found.
-
toExecutionTableStyle
Depending on the runtime environment (Windows, Linux, JUnit) we prefer different table styles as depending on the runtime environment not all characters used by the various table styles may be available.- Returns:
- The
TableStyleby default fitting best for the current environment.
-