Module org.refcodes.textual
Package org.refcodes.textual
Interface TableStyleAccessor.TableStyleProperty
-
- All Superinterfaces:
TableStyleAccessor,TableStyleAccessor.TableStyleMutator
- Enclosing interface:
- TableStyleAccessor
public static interface TableStyleAccessor.TableStyleProperty extends TableStyleAccessor, TableStyleAccessor.TableStyleMutator
Provides aTableStyleproperty.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.textual.TableStyleAccessor
TableStyleAccessor.TableStyleBuilder<B extends TableStyleAccessor.TableStyleBuilder<?>>, TableStyleAccessor.TableStyleMutator, TableStyleAccessor.TableStyleProperty
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default TableStyleletTableStyle(TableStyle aTableStyle)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTableStyle(setter) as ofTableStyleAccessor.TableStyleMutator.setTableStyle(TableStyle)and returns the very same value (getter).-
Methods inherited from interface org.refcodes.textual.TableStyleAccessor
getTableStyle
-
Methods inherited from interface org.refcodes.textual.TableStyleAccessor.TableStyleMutator
setTableStyle
-
-
-
-
Method Detail
-
letTableStyle
default TableStyle letTableStyle(TableStyle aTableStyle)
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTableStyle(setter) as ofTableStyleAccessor.TableStyleMutator.setTableStyle(TableStyle)and returns the very same value (getter).- Parameters:
aTableStyle- TheTableStyleto set (viaTableStyleAccessor.TableStyleMutator.setTableStyle(TableStyle)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
-