-
- Type Parameters:
B- the generic type
- All Superinterfaces:
TextAccessor,TextAccessor.TextBuilder<Text<B>>,TextAccessor.TextMutator,TextAccessor.TextProperty,TextAccessor.TextProvider
- All Known Implementing Classes:
AsciiArtBuilder,EscapeTextBuilder,HorizAlignTextBuilder,MoreTextBuilder,OverwriteTextBuilder,ReplaceTextBuilder,SecretHintBuilder,TextBlockBuilder,TextBorderBuilder,TruncateTextBuilder,VertAlignTextBuilder
public interface Text<B extends Text<B>> extends TextAccessor.TextProperty, TextAccessor.TextBuilder<Text<B>>, TextAccessor.TextProvider
The Interface Text.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.textual.TextAccessor
TextAccessor.TextBuilder<B extends TextAccessor.TextBuilder<B>>, TextAccessor.TextMutator, TextAccessor.TextProperty, TextAccessor.TextProvider
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description StringtoString(String... aText)Race condition safe shortcut for usingwithText(String...)followed byTextAccessor.TextProvider.toString().String[]toStrings(String... aText)Race condition safe shortcut for usingwithText(String...)followed byTextAccessor.TextProvider.toStrings().default BwithText(String... aText)Sets the text for the text property.-
Methods inherited from interface org.refcodes.textual.TextAccessor
getText
-
Methods inherited from interface org.refcodes.textual.TextAccessor.TextBuilder
withText
-
Methods inherited from interface org.refcodes.textual.TextAccessor.TextMutator
setText, setText
-
Methods inherited from interface org.refcodes.textual.TextAccessor.TextProperty
letText, letText
-
Methods inherited from interface org.refcodes.textual.TextAccessor.TextProvider
toString, toStrings
-
-
-
-
Method Detail
-
withText
default B withText(String... aText)
Sets the text for the text property.- Specified by:
withTextin interfaceTextAccessor.TextBuilder<B extends Text<B>>- Parameters:
aText- The text to be stored by the text property.- Returns:
- The builder for applying multiple build operations.
-
toStrings
String[] toStrings(String... aText)
Race condition safe shortcut for usingwithText(String...)followed byTextAccessor.TextProvider.toStrings(). Implementation requirements: This method must not(!) be implemented by callingwithText(String...)followed byTextAccessor.TextProvider.toStrings()(do not change the text property) as this would not be thread safe!- Parameters:
aText- The text to be processed.- Returns:
- The according resulting
Stringarray
-
toString
String toString(String... aText)
Race condition safe shortcut for usingwithText(String...)followed byTextAccessor.TextProvider.toString(). Implementation requirements: This method must not(!) be implemented by callingwithText(String...)followed byTextAccessor.TextProvider.toString()(do not change the text property) as this would not be thread safe!- Parameters:
aText- The text to be processed.- Returns:
- The according resulting
String
-
-