-
- All Known Subinterfaces:
Text<B>
- All Known Implementing Classes:
AsciiArtBuilder,EscapeTextBuilder,HorizAlignTextBuilder,MoreTextBuilder,OverwriteTextBuilder,ReplaceTextBuilder,SecretHintBuilder,TextBlockBuilder,TextBorderBuilder,TruncateTextBuilder,VertAlignTextBuilder
- Enclosing interface:
- TextAccessor
public static interface TextAccessor.TextProviderA provider interface provides a "toSomething(?)" method which converts a given instance into something else. TheTextAccessor.TextProviderconverts an implementing instance's state intoStringinstances.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description StringtoString()TheStringbeing build by the builder upon the settings of the attributes.String[]toStrings()TheStrings being build by the builder upon the settings of the attributes.
-
-
-
Method Detail
-
toStrings
String[] toStrings()
TheStrings being build by the builder upon the settings of the attributes.- Returns:
- The according resulting
Stringarray
-
toString
String toString()
TheStringbeing build by the builder upon the settings of the attributes. In case more then one line has been set as input and the functionality of the builder is applied to each line in separate, then this method returns all of them lines concatenated with a line break between each of them (implementation depended).
-
-