Interface TextBoxGridAccessor.TextBoxGridBuilder<B extends TextBoxGridAccessor.TextBoxGridBuilder<?>>
- Type Parameters:
B- The builder which implements theTextBoxGridAccessor.TextBoxGridBuilder.
- All Known Implementing Classes:
TextBorderBuilder
- Enclosing interface:
TextBoxGridAccessor
public static interface TextBoxGridAccessor.TextBoxGridBuilder<B extends TextBoxGridAccessor.TextBoxGridBuilder<?>>
Provides a mutator for an
TextBoxGrid property.-
Method Summary
Modifier and TypeMethodDescriptionwithTextBoxGrid(TextBoxGrid aTextBoxGrid) Sets the rowsTextBoxGridto use returns this builder as of the Builder-Pattern.default BwithTextBoxGrid(TextBoxStyle aTextBoxStyle) Sets the rowsTextBoxGridto use returns this builder as of the Builder-Pattern.
-
Method Details
-
withTextBoxGrid
Sets the rowsTextBoxGridto use returns this builder as of the Builder-Pattern.- Parameters:
aTextBoxGrid- TheTextBoxGridto be used.- Returns:
- This
TextBoxGridAccessor.TextBoxGridBuilderinstance to continue configuration.
-
withTextBoxGrid
Sets the rowsTextBoxGridto use returns this builder as of the Builder-Pattern.- Parameters:
aTextBoxStyle- TheTextBoxStyleto be used.- Returns:
- This
TextBoxGridAccessor.TextBoxGridBuilderinstance to continue configuration.
-