Module org.refcodes.textual
Package org.refcodes.textual
Interface TextBoxGridAccessor.TextBoxGridProperty
- All Superinterfaces:
TextBoxGridAccessor,TextBoxGridAccessor.TextBoxGridMutator
- All Known Implementing Classes:
TextBorderBuilder
- Enclosing interface:
TextBoxGridAccessor
public static interface TextBoxGridAccessor.TextBoxGridProperty
extends TextBoxGridAccessor, TextBoxGridAccessor.TextBoxGridMutator
Provides a
TextBoxGrid property.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.textual.TextBoxGridAccessor
TextBoxGridAccessor.TextBoxGridBuilder<B extends TextBoxGridAccessor.TextBoxGridBuilder<?>>, TextBoxGridAccessor.TextBoxGridMutator, TextBoxGridAccessor.TextBoxGridProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault TextBoxGridletTextBoxGrid(TextBoxGrid aTextBoxGrid) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTextBoxGrid(setter) as ofTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid)and returns the very same value (getter).default TextBoxGridletTextBoxGrid(TextBoxStyle aTextBoxStyle) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTextBoxGrid(setter) as ofTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid)and returns the very same value (getter).Methods inherited from interface org.refcodes.textual.TextBoxGridAccessor
getTextBoxGridMethods inherited from interface org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator
setTextBoxGrid, setTextBoxGrid
-
Method Details
-
letTextBoxGrid
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTextBoxGrid(setter) as ofTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid)and returns the very same value (getter).- Parameters:
aTextBoxGrid- TheTextBoxGridto set (viaTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
letTextBoxGrid
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTextBoxGrid(setter) as ofTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid)and returns the very same value (getter).- Parameters:
aTextBoxStyle- TheTextBoxStyleto set (viaTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-