Class TextBoxGridImpl

java.lang.Object
org.refcodes.mixin.AbstractBoxGrid<Character>
org.refcodes.textual.TextBoxGridImpl
All Implemented Interfaces:
BoxGrid<Character>, TextBoxGrid

public class TextBoxGridImpl extends AbstractBoxGrid<Character> implements TextBoxGrid
Implementation of the TextBoxGrid interface.
  • Constructor Details

    • TextBoxGridImpl

      public TextBoxGridImpl(String[] aTextBoxGrid)
      For easy of use this constructor uses a String array representing the box grid characters to be used. The array may look as follows: { "┌─┬─┐", "│ │ │", "├─┼─┤", "│ │ │", "└─┴─┘" }
      Parameters:
      aTextBoxGrid - The String array "painting" the grid.