Enum Class TextBoxStyle

java.lang.Object
java.lang.Enum<TextBoxStyle>
org.refcodes.textual.TextBoxStyle
All Implemented Interfaces:
Serializable, Comparable<TextBoxStyle>, Constable, BoxGrid<Character>, TextBoxGrid

public enum TextBoxStyle extends Enum<TextBoxStyle> implements TextBoxGrid
The TextBoxStyle enumeration defines character sets for various box grid representations. For example Box Drawing (Unicode block) characters are used, which are not available on every system or terminal: ╔══════════════════════════════════════════════════════════════════════════╗ ║ U+250x ─ ━ │ ┃ ┄ ┅ ┆ ┇ ┈ ┉ ┊ ┋ ┌ ┍ ┎ ┏ ║ ║ U+251x ┐ ┑ ┒ ┓ └ ┕ ┖ ┗ ┘ ┙ ┚ ┛ ├ ┝ ┞ ┟ ║ ║ U+252x ┠ ┡ ┢ ┣ ┤ ┥ ┦ ┧ ┨ ┩ ┪ ┫ ┬ ┭ ┮ ┯ ║ ║ U+253x ┰ ┱ ┲ ┳ ┴ ┵ ┶ ┷ ┸ ┹ ┺ ┻ ┼ ┽ ┾ ┿ ║ ║ U+254x ╀ ╁ ╂ ╃ ╄ ╅ ╆ ╇ ╈ ╉ ╊ ╋ ╌ ╍ ╎ ╏ ║ ║ U+255x ═ ║ ╒ ╓ ╔ ╕ ╖ ╗ ╘ ╙ ╚ ╛ ╜ ╝ ╞ ╟ ║ ║ U+256x ╠ ╡ ╢ ╣ ╤ ╥ ╦ ╧ ╨ ╩ ╪ ╫ ╬ ╭ ╮ ╯ ║ ║ U+257x ╰ ╱ ╲ ╳ ╴ ╵ ╶ ╷ ╸ ╹ ╺ ╻ ╼ ╽ ╾ ╿ ║ ╚══════════════════════════════════════════════════════════════════════════╝ Therefore plain ASCII character sets such as ASCII are provided as well.
  • Enum Constant Details

    • SINGLE

      public static final TextBoxStyle SINGLE
      Representation of the following text box grid: ┌─┬─┐ │ │ │ ├─┼─┤ │ │ │ └─┴─┘
    • SINGLE_DASHED

      public static final TextBoxStyle SINGLE_DASHED
      Representation of the following text box grid: ┌─┬─┐ │ │ │ ├─┼─┤ │ │ │ └─┴─┘
    • SINGLE_DOUBLE

      public static final TextBoxStyle SINGLE_DOUBLE
      Representation of the following text box grid: ╒═╤═╕ │ │ │ ╞═╪═╡ │ │ │ ╘═╧═╛
    • DOUBLE_SINGLE

      public static final TextBoxStyle DOUBLE_SINGLE
      Representation of the following text box grid: ╓─╥─╖ ║ ║ ║ ╟─╫─╢ ║ ║ ║ ╙─╨─╜
    • DOUBLE

      public static final TextBoxStyle DOUBLE
      Representation of the following text box grid: ╔═╦═╗ ║ ║ ║ ╠═╬═╣ ║ ║ ║ ╚═╩═╝
    • BOLD

      public static final TextBoxStyle BOLD
      Representation of the following text box grid: ┏━┳━┓ ┃ ┃ ┃ ┣━╋━┫ ┃ ┃ ┃ ┗━┻━┛
    • HYBRID_BOLD_SINGLE

      public static final TextBoxStyle HYBRID_BOLD_SINGLE
      Representation of the following text box grid: ┏━┳━┓ ┃ ┃ ┃ ┠─╂─┨ ┃ ┃ ┃ ┗━┻━┛
    • HYBRID_SINGLE_BOLD

      public static final TextBoxStyle HYBRID_SINGLE_BOLD
      Representation of the following text box grid: ┌─┰─┐ │ ┃ │ ┝━╋━┥ │ ┃ │ └─┸─┘
    • BOLD_HEADER_SINGLE_BODY

      public static final TextBoxStyle BOLD_HEADER_SINGLE_BODY
      Representation of the following text box grid: ┏━┳━┓ ┃ ┃ ┃ ┡━╇━┩ │ │ │ └─┴─┘
    • SINGLE_HEADER_BOLD_BODY

      public static final TextBoxStyle SINGLE_HEADER_BOLD_BODY
      Representation of the following text box grid: ┌─┬─┐ │ │ │ ┢━╈━┪ ┃ ┃ ┃ ┗━┻━┛
    • HYBRID_BOLD_HEADER_SINGLE_BODY

      public static final TextBoxStyle HYBRID_BOLD_HEADER_SINGLE_BODY
      Representation of the following text box grid: ┏━┯━┓ ┃ │ ┃ ┡━┿━┩ │ │ │ └─┴─┘
    • HYBRID_SINGLE_HEADER_BOLD_BODY

      public static final TextBoxStyle HYBRID_SINGLE_HEADER_BOLD_BODY
      Representation of the following text box grid: ┌─┬─┐ │ │ │ ┢━┿━┪ ┃ │ ┃ ┗━┷━┛
    • HYBRID_DOUBLE_SINGLE

      public static final TextBoxStyle HYBRID_DOUBLE_SINGLE
      Representation of the following text box grid: ╔═╤═╗ ║ │ ║ ╠═╪═╣ ║ │ ║ ╚═╧═╝
    • HYBRID_SINGLE_DOUBLE

      public static final TextBoxStyle HYBRID_SINGLE_DOUBLE
      Representation of the following text box grid: ┌─╥─┐ │ ║ │ ├─╫─┤ │ ║ │ └─╨─┘
    • DOUBLE_BORDER_SINGLE_CONTENT

      public static final TextBoxStyle DOUBLE_BORDER_SINGLE_CONTENT
      Representation of the following text box grid: ╔═╤═╗ ║ │ ║ ╟─┼─╢ ║ │ ║ ╚═╧═╝
    • SINGLE_BORDER_DOUBLE_CONTENT

      public static final TextBoxStyle SINGLE_BORDER_DOUBLE_CONTENT
      Representation of the following text box grid: ┌─╥─┐ │ ║ │ ╞═╬═╡ │ ║ │ └─╨─┘
    • ASCII

      public static final TextBoxStyle ASCII
      Representation of the following text box grid: /-+-\ | | | +-+-+ | | | \-+-/
    • BLANK

      public static final TextBoxStyle BLANK
      Representation of the following text box grid: " " " " " " " " " "
    • SINGLE_BLANK

      public static final TextBoxStyle SINGLE_BLANK
      Representation of the following text box grid: " ─ ─ " " " " ─ ─ " " " " ─ ─ "
    • ASCII_BLANK

      public static final TextBoxStyle ASCII_BLANK
      Representation of the following text box grid: " - - " " " " - - " " " " - - "
  • Field Details

    • UNICODE_TEXT_BOX_STYLE

      public static final TextBoxStyle UNICODE_TEXT_BOX_STYLE
      Style supported Unicode capable terminals (when not being under test).
    • WINDOWS_TEXT_BOX_STYLE

      public static final TextBoxStyle WINDOWS_TEXT_BOX_STYLE
      Style displayed for sure when being on a Windows machine.
    • ASCII_TEXT_BOX_STYLE

      public static final TextBoxStyle ASCII_TEXT_BOX_STYLE
      Style displayed for sure when being under test (e.g. JUnit) or in a Cp1252 or a plain "xterm".
  • Method Details