Enum Class TextFormatMode

java.lang.Object
java.lang.Enum<TextFormatMode>
org.refcodes.textual.TextFormatMode
All Implemented Interfaces:
Serializable, Comparable<TextFormatMode>, Constable

public enum TextFormatMode extends Enum<TextFormatMode>
Determines how to format a text (in a table), e.g. do not format anything, format the text only or format the whole cell containing the text, even blank lines (important for the background).