Uses of Interface
org.refcodes.textual.ColumnFormatMetrics
-
Uses of ColumnFormatMetrics in org.refcodes.textual
Subinterfaces of ColumnFormatMetrics in org.refcodes.textualModifier and TypeInterfaceDescriptioninterfaceThe Interface ColumnSetupMetrics.Classes in org.refcodes.textual that implement ColumnFormatMetricsModifier and TypeClassDescriptionclassImplementation of theColumnFormatMetricsinterface.classImplementation of theColumnFormatMetricsinterface.Methods in org.refcodes.textual that return ColumnFormatMetricsModifier and TypeMethodDescriptiondefault ColumnFormatMetricsColumnFormatMetrics.withColumnWidth(int aColumnWidth) ColumnFormatMetricsImpl.withColumnWidth(int aColumnWidth) default ColumnFormatMetricsColumnFormatMetrics.withColumnWidthType(ColumnWidthType aColumnWidthType) With column width type.default ColumnFormatMetricsColumnFormatMetrics.withEscapeCode(String aEscapeCode) Sets an ANSI Escape-Code for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withHeaderEscapeCode(String aEscapeCode) Sets an ANSI Escape-Code for the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withHeaderEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withHeaderHorizAlignTextMode(HorizAlignTextMode aHorizAlignTextMode) Sets an alignment mode for the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withHeaderMoreTextMode(MoreTextMode aMoreTextMode) Sets a more-text mode for the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withHeaderSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withHeaderTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withHorizAlignTextMode(HorizAlignTextMode aHorizAlignTextMode) Sets the horizontal align text mode for the horizontal align text mode property.default ColumnFormatMetricsColumnFormatMetrics.withMoreTextMode(MoreTextMode aMoreTextMode) Sets the more-text mode for the more-text mode property.default ColumnFormatMetricsColumnFormatMetrics.withRowEscapeCode(String aEscapeCode) Sets an ANSI Escape-Code for the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withRowEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the row and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withRowHorizAlignTextMode(HorizAlignTextMode aHorizAlignTextMode) Sets an alignment mode for the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withRowMoreTextMode(MoreTextMode aMoreTextMode) Sets a more-text mode for the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withRowSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withRowTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withSplitTextMode(SplitTextMode aSplitTextMode) Sets the split-text mode for the split-text mode property.default ColumnFormatMetricsColumnFormatMetrics.withTextFormatMode(TextFormatMode aTextFormatMode) Sets the text-format mode for the text-format mode property.Methods in org.refcodes.textual with parameters of type ColumnFormatMetricsModifier and TypeMethodDescriptiondefault voidColumnFormatMetrics.fromColumnFormatMetrics(ColumnFormatMetrics aColumnFormatMetrics) From column format metrics.TableBuilder.withColumnFormatMetrics(ColumnFormatMetrics aColumnFormatMetrics) Sets the current column's (the last added one with theTableBuilder.addColumn()method) format (including the width) and returns thisTableBuilderinstance as of the Builder-Pattern.