Uses of Interface
org.refcodes.textual.EscapeCodeFactory
-
Uses of EscapeCodeFactory in org.refcodes.textual
Methods in org.refcodes.textual that return EscapeCodeFactoryModifier and TypeMethodDescriptionColumnFormatMetrics.getHeaderEscapeCodeFactory()Gets the ANSI Escape-Code factory for the header.ColumnFormatMetrics.getRowEscapeCodeFactory()Gets the ANSI Escape-Code factory for the row.Methods in org.refcodes.textual with parameters of type EscapeCodeFactoryModifier and TypeMethodDescriptionvoidColumnFormatMetrics.setEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows.voidColumnFormatMetrics.setHeaderEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header.voidColumnFormatMetrics.setRowEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the row.ColumnFormatMetrics.withEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns this instance as of the Builder-Pattern.ColumnSetupMetrics.withEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns this instance as of the Builder-Pattern.ColumnFormatMetrics.withHeaderEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.ColumnSetupMetrics.withHeaderEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.ColumnFormatMetrics.withRowEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the row and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.ColumnSetupMetrics.withRowEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the row and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.