Uses of Enum Class
org.refcodes.textual.SplitTextMode
-
Uses of SplitTextMode in org.refcodes.textual
Methods in org.refcodes.textual that return SplitTextModeModifier and TypeMethodDescriptionColumnFormatMetrics.getHeaderSplitTextMode()Returns theSplitTextModefor the header.ColumnFormatMetricsImpl.getHeaderSplitTextMode()Returns theSplitTextModefor the header.ColumnFormatMetrics.getRowSplitTextMode()Returns theSplitTextModefor the row.ColumnFormatMetricsImpl.getRowSplitTextMode()Returns theSplitTextModefor the row.SplitTextModeAccessor.getSplitTextMode()Retrieves the split-text mode from the split-text mode property.TextBlockBuilder.getSplitTextMode()Retrieves the split text mode from the split text mode property.default SplitTextModeSplitTextModeAccessor.SplitTextModeProperty.letSplitTextMode(SplitTextMode aSplitTextMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSplitTextMode(setter) as ofSplitTextModeAccessor.SplitTextModeMutator.setSplitTextMode(SplitTextMode)and returns the very same value (getter).static SplitTextModeReturns the enum constant of this class with the specified name.static SplitTextMode[]SplitTextMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.textual with parameters of type SplitTextModeModifier and TypeMethodDescriptionstatic String[]TextBlockBuilder.asTextBlock(String[] aText, int aColumnWidth, HorizAlignTextMode aHorizAlignTextMode, SplitTextMode aSplitTextMode, char aFillChar) static String[]TextBlockBuilder.asTextBlock(String[] aText, int aColumnWidth, HorizAlignTextMode aHorizAlignTextMode, SplitTextMode aSplitTextMode, char aFillChar, boolean hasAnsiEscapeCodes) static String[]TextBlockBuilder.asTextBlock(String[] aText, int aColumnWidth, SplitTextMode aSplitTextMode) static String[]TextBlockBuilder.asTextBlock(String[] aText, int aColumnWidth, SplitTextMode aSplitTextMode, boolean hasAnsiEscapeCodes) static String[]TextBlockBuilder.asTextBlock(String aText, int aColumnWidth, HorizAlignTextMode aHorizAlignTextMode, SplitTextMode aSplitTextMode, char aFillChar) static String[]TextBlockBuilder.asTextBlock(String aText, int aColumnWidth, HorizAlignTextMode aHorizAlignTextMode, SplitTextMode aSplitTextMode, char aFillChar, boolean hasAnsiEscapeCodes) static String[]TextBlockBuilder.asTextBlock(String aText, int aColumnWidth, SplitTextMode aSplitTextMode) static String[]TextBlockBuilder.asTextBlock(String aText, int aColumnWidth, SplitTextMode aSplitTextMode, boolean hasAnsiEscapeCodes) default SplitTextModeSplitTextModeAccessor.SplitTextModeProperty.letSplitTextMode(SplitTextMode aSplitTextMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSplitTextMode(setter) as ofSplitTextModeAccessor.SplitTextModeMutator.setSplitTextMode(SplitTextMode)and returns the very same value (getter).voidColumnFormatMetrics.setHeaderSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the header.voidColumnFormatMetricsImpl.setHeaderSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the header.voidColumnFormatMetrics.setRowSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the row.voidColumnFormatMetricsImpl.setRowSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the row.default voidColumnFormatMetrics.setSplitTextMode(SplitTextMode aSplitTextMode) voidSplitTextModeAccessor.SplitTextModeMutator.setSplitTextMode(SplitTextMode aSplitTextMode) Sets the split-text mode for the split-text mode property.voidTextBlockBuilder.setSplitTextMode(SplitTextMode aSplitTextMode) Sets the split text mode for the split text mode property.TableBuilder.withColumnSplitTextMode(SplitTextMode aSplitTextMode) Sets the column's line split mode for the header and the rows and returns thisTableBuilderinstance as of the Builder-Pattern.TableBuilder.withHeaderColumnSplitTextMode(SplitTextMode aSplitTextMode) Sets the column's header line split mode for the header and the rows and returns thisTableBuilderinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withHeaderSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnSetupMetricsColumnSetupMetrics.withHeaderSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.TableBuilder.withHeaderSplitTextMode(SplitTextMode aSplitTextMode) Sets an overall line split mode for the header and returns thisTableBuilderinstance as of the Builder-Pattern.TableBuilder.withRowColumnSplitTextMode(SplitTextMode aSplitTextMode) Sets the column's header line split mode for the header and the rows and returns thisTableBuilderinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withRowSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnSetupMetricsColumnSetupMetrics.withRowSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.TableBuilder.withRowSplitTextMode(SplitTextMode aSplitTextMode) Sets an overall line split mode for the rows and returns thisTableBuilderinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withSplitTextMode(SplitTextMode aSplitTextMode) Sets the split-text mode for the split-text mode property.default ColumnSetupMetricsColumnSetupMetrics.withSplitTextMode(SplitTextMode aSplitTextMode) Sets the split-text mode for the split-text mode property.SplitTextModeAccessor.SplitTextModeBuilder.withSplitTextMode(SplitTextMode aSplitTextMode) Sets the split-text mode for the split-text mode property.TableBuilder.withSplitTextMode(SplitTextMode aSplitTextMode) Sets an overall line split mode for the header and the rows and returns thisTableBuilderinstance as of the Builder-Pattern.TextBlockBuilder.withSplitTextMode(SplitTextMode aSplitTextMode) Sets the split text mode for the split text mode property.