Uses of Enum Class
org.refcodes.textual.TextFormatMode
-
Uses of TextFormatMode in org.refcodes.textual
Subclasses with type arguments of type TextFormatMode in org.refcodes.textualModifier and TypeClassDescriptionenumDetermines how to format a text (in a table), e.g. do not format anything, format the text only or format the whole cell containing the text, even blank lines (important for the background).Methods in org.refcodes.textual that return TextFormatModeModifier and TypeMethodDescriptionColumnFormatMetrics.getHeaderTextFormatMode()Returns theTextFormatModefor the header.ColumnFormatMetricsImpl.getHeaderTextFormatMode()Returns theTextFormatModefor the header.ColumnFormatMetrics.getRowTextFormatMode()Returns theTextFormatModefor the row.ColumnFormatMetricsImpl.getRowTextFormatMode()Returns theTextFormatModefor the row.TextFormatModeAccessor.getTextFormatMode()Retrieves the text-format mode from the text-format mode property.default TextFormatModeTextFormatModeAccessor.TextFormatModeProperty.letTextFormatMode(TextFormatMode aTextFormatMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTextFormatMode(setter) as ofTextFormatModeAccessor.TextFormatModeMutator.setTextFormatMode(TextFormatMode)and returns the very same value (getter).static TextFormatModeReturns the enum constant of this class with the specified name.static TextFormatMode[]TextFormatMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.textual with parameters of type TextFormatModeModifier and TypeMethodDescriptiondefault TextFormatModeTextFormatModeAccessor.TextFormatModeProperty.letTextFormatMode(TextFormatMode aTextFormatMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTextFormatMode(setter) as ofTextFormatModeAccessor.TextFormatModeMutator.setTextFormatMode(TextFormatMode)and returns the very same value (getter).voidColumnFormatMetrics.setHeaderTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the header.voidColumnFormatMetricsImpl.setHeaderTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the header.voidColumnFormatMetrics.setRowTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the row.voidColumnFormatMetricsImpl.setRowTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the row.default voidColumnFormatMetrics.setTextFormatMode(TextFormatMode aTextFormatMode) Sets the text-format mode for the text-format mode property.voidTextFormatModeAccessor.TextFormatModeMutator.setTextFormatMode(TextFormatMode aTextFormatMode) Sets the text-format mode for the text-format mode property.TableBuilder.withColumnTextFormatMode(TextFormatMode aTextFormatMode) Sets the column's format mode for the header and the rows and returns thisTableBuilderinstance as of the Builder-Pattern.TableBuilder.withHeaderColumnTextFormatMode(TextFormatMode aTextFormatMode) Sets the column's header format mode for the header and the rows and returns thisTableBuilderinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withHeaderTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnSetupMetricsColumnSetupMetrics.withHeaderTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.TableBuilder.withHeaderTextFormatMode(TextFormatMode aTextFormatMode) Sets an overall format mode for the header and returns thisTableBuilderinstance as of the Builder-Pattern.TableBuilder.withRowColumnTextFormatMode(TextFormatMode aTextFormatMode) Sets the column's row format mode for the header and the rows and returns thisTableBuilderinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withRowTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnSetupMetricsColumnSetupMetrics.withRowTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.TableBuilder.withRowTextFormatMode(TextFormatMode aTextFormatMode) Sets an overall format mode for the rows and returns thisTableBuilderinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withTextFormatMode(TextFormatMode aTextFormatMode) Sets the text-format mode for the text-format mode property.default ColumnSetupMetricsColumnSetupMetrics.withTextFormatMode(TextFormatMode aTextFormatMode) Sets the text-format mode for the text-format mode property.TableBuilder.withTextFormatMode(TextFormatMode aTextFormatMode) Sets an overall format mode for the header and the rows and returns thisTableBuilderinstance as of the Builder-Pattern.TextFormatModeAccessor.TextFormatModeBuilder.withTextFormatMode(TextFormatMode aTextFormatMode) Sets the text-format mode for the text-format mode property.