Interface ColumnFormatMetrics
- All Superinterfaces:
org.refcodes.mixin.ColumnWidthAccessor, org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthBuilder<ColumnWidthMetrics>, org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthMutator, org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthProperty, ColumnWidthMetrics, HorizAlignTextModeAccessor.HorizAlignTextModeBuilder<ColumnFormatMetrics>, HorizAlignTextModeAccessor.HorizAlignTextModeMutator, MoreTextModeAccessor.MoreTextModeBuilder<ColumnFormatMetrics>, MoreTextModeAccessor.MoreTextModeMutator, SplitTextModeAccessor.SplitTextModeBuilder<ColumnFormatMetrics>, SplitTextModeAccessor.SplitTextModeMutator, TextFormatModeAccessor.TextFormatModeBuilder<ColumnFormatMetrics>, TextFormatModeAccessor.TextFormatModeMutator
- All Known Subinterfaces:
ColumnSetupMetrics
- All Known Implementing Classes:
ColumnFormatMetricsImpl, ColumnSetupMetricsImpl
public interface ColumnFormatMetrics
extends ColumnWidthMetrics, SplitTextModeAccessor.SplitTextModeMutator, SplitTextModeAccessor.SplitTextModeBuilder<ColumnFormatMetrics>, TextFormatModeAccessor.TextFormatModeMutator, TextFormatModeAccessor.TextFormatModeBuilder<ColumnFormatMetrics>, HorizAlignTextModeAccessor.HorizAlignTextModeMutator, HorizAlignTextModeAccessor.HorizAlignTextModeBuilder<ColumnFormatMetrics>, MoreTextModeAccessor.MoreTextModeMutator, MoreTextModeAccessor.MoreTextModeBuilder<ColumnFormatMetrics>
The Interface ColumnFormatMetrics.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.ColumnWidthAccessor
org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthBuilder<B>, org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthMutator, org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault voidfromColumnFormatMetrics(ColumnFormatMetrics aColumnFormatMetrics) From column format metrics.Returns the ANSI Escape-Code for the header.Gets the ANSI Escape-Code factory for the header.Gets the alignment mode for the header.Gets the alignment mode for the header.Returns theSplitTextModefor the header.Returns theTextFormatModefor the header.Returns the ANSI Escape-Code for the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.Gets the ANSI Escape-Code factory for the row.Gets the alignment mode for the row.Gets the alignment mode for the row.Returns theSplitTextModefor the row.Returns theTextFormatModefor the row.default voidsetEscapeCode(String aEscapeCode) Sets an ANSI Escape-Code for the header and the rows.default voidsetEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows.voidsetHeaderEscapeCode(String aEscapeCode) Sets an ANSI Escape-Code for the header.voidsetHeaderEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header.voidsetHeaderHorizAlignTextMode(HorizAlignTextMode aHorizAlignTextMode) Sets an alignment mode for the header.voidsetHeaderMoreTextMode(MoreTextMode aMoreTextMode) Sets a more-text mode for the header.voidsetHeaderSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the header.voidsetHeaderTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the header.default voidsetHorizAlignTextMode(HorizAlignTextMode aHorizAlignTextMode) Sets the horizontal align text mode for the horizontal align text mode property.default voidsetMoreTextMode(MoreTextMode aMoreTextMode) Sets the more-text mode for the more-text mode property.voidsetRowEscapeCode(String aEscapeCode) Sets an ANSI Escape-Code for the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.voidsetRowEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the row.voidsetRowHorizAlignTextMode(HorizAlignTextMode aHorizAlignTextMode) Sets an alignment mode for the row.voidsetRowMoreTextMode(MoreTextMode aMoreTextMode) Sets a more-text mode for the row.voidsetRowSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the row.voidsetRowTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the row.default voidsetSplitTextMode(SplitTextMode aSplitTextMode) Sets the split-text mode for the split-text mode property.default voidsetTextFormatMode(TextFormatMode aTextFormatMode) Sets the text-format mode for the text-format mode property.toHeaderEscapeCode(Object aIdentifier) Determines the ANSI Escape-Code by evaluating the provided TID: If anEscapeCodeFactoryhas been set viasetEscapeCodeFactory(EscapeCodeFactory)and the factory returns a value different to null, then this value is returned.toRowEscapeCode(Object aIdentifier) Determines the ANSI Escape-Code by evaluating the provided TID: If anEscapeCodeFactoryhas been set viasetEscapeCodeFactory(EscapeCodeFactory)and the factory returns a value different to null, then this value is returned.default ColumnFormatMetricswithColumnWidth(int aColumnWidth) default ColumnFormatMetricswithColumnWidthType(ColumnWidthType aColumnWidthType) With column width type.default ColumnFormatMetricswithEscapeCode(String aEscapeCode) Sets an ANSI Escape-Code for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithHeaderEscapeCode(String aEscapeCode) Sets an ANSI Escape-Code for the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithHeaderEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithHeaderHorizAlignTextMode(HorizAlignTextMode aHorizAlignTextMode) Sets an alignment mode for the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithHeaderMoreTextMode(MoreTextMode aMoreTextMode) Sets a more-text mode for the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithHeaderSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithHeaderTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithHorizAlignTextMode(HorizAlignTextMode aHorizAlignTextMode) Sets the horizontal align text mode for the horizontal align text mode property.default ColumnFormatMetricswithMoreTextMode(MoreTextMode aMoreTextMode) Sets the more-text mode for the more-text mode property.default ColumnFormatMetricswithRowEscapeCode(String aEscapeCode) Sets an ANSI Escape-Code for the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithRowEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the row and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithRowHorizAlignTextMode(HorizAlignTextMode aHorizAlignTextMode) Sets an alignment mode for the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithRowMoreTextMode(MoreTextMode aMoreTextMode) Sets a more-text mode for the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithRowSplitTextMode(SplitTextMode aSplitTextMode) Sets theSplitTextModefor the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithRowTextFormatMode(TextFormatMode aTextFormatMode) Sets theTextFormatModefor the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricswithSplitTextMode(SplitTextMode aSplitTextMode) Sets the split-text mode for the split-text mode property.default ColumnFormatMetricswithTextFormatMode(TextFormatMode aTextFormatMode) Sets the text-format mode for the text-format mode property.Methods inherited from interface org.refcodes.mixin.ColumnWidthAccessor
getColumnWidthMethods inherited from interface org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthMutator
setColumnWidthMethods inherited from interface org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthProperty
letColumnWidthMethods inherited from interface ColumnWidthMetrics
fromColumnWidthMetrics, getColumnWidthType, setColumnWidthType
-
Method Details
-
withEscapeCode
Sets an ANSI Escape-Code for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern. In case an ANSI Escape-Code is set, then the ANSI Escape-Code is prepended and an ANSI Reset-Code is appended to the according text being printed.- Parameters:
aEscapeCode- TheStringto be used for ANSI escaping.- Returns:
- This
ColumnFormatMetricsinstance to continue configuration.
-
withEscapeCodeFactory
Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern. In case an ANSI Escape-Code has been determined by theEscapeCodeFactory, then the ANSI Escape-Code is prepended and an ANSI Reset-Code is appended to the according text being printed.- Parameters:
aEscapeCodeFactory- TheEscapeCodeFactoryto be used for determining ANSI escaping.- Returns:
- This
ColumnFormatMetricsinstance to continue configuration.
-
setEscapeCodeFactory
Sets an ANSI Escape-Code factory for the header and the rows. In case an ANSI Escape-Code has been determined by theEscapeCodeFactory, then the ANSI Escape-Code is prepended and an ANSI Reset-Code is appended to the according text being printed.- Parameters:
aEscapeCodeFactory- TheEscapeCodeFactoryto be used for determining ANSI escaping.
-
withHeaderEscapeCodeFactory
Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern. In case an ANSI Escape-Code has been determined by theEscapeCodeFactory, then the ANSI Escape-Code is prepended and an ANSI Reset-Code is appended to the according text being printed.- Parameters:
aEscapeCodeFactory- TheEscapeCodeFactoryto be used for determining ANSI escaping.- Returns:
- the column format metrics
-
setHeaderEscapeCodeFactory
Sets an ANSI Escape-Code factory for the header. In case an ANSI Escape-Code is set, then the ANSI Escape-Code is prepended and an ANSI Reset-Code is appended to the according text being printed.- Parameters:
aEscapeCodeFactory- TheEscapeCodeFactoryto be used for determining ANSI escaping.
-
getHeaderEscapeCodeFactory
EscapeCodeFactory getHeaderEscapeCodeFactory()Gets the ANSI Escape-Code factory for the header. In case an ANSI Escape-Code is set, then the ANSI Escape-Code is prepended and an ANSI Reset-Code is appended to the according text being printed.- Returns:
- The
EscapeCodeFactoryto be used for determining ANSI escaping.
-
toHeaderEscapeCode
Determines the ANSI Escape-Code by evaluating the provided TID: If anEscapeCodeFactoryhas been set viasetEscapeCodeFactory(EscapeCodeFactory)and the factory returns a value different to null, then this value is returned. Else the value returned bygetHeaderEscapeCode()is returned as fallback.- Parameters:
aIdentifier- The TID for which to lookup an Escape-Code.- Returns:
- The identified Escape-Code or null if none was identifiable.
-
withRowEscapeCodeFactory
Sets an ANSI Escape-Code factory for the row and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern. In case an ANSI Escape-Code has been determined by theEscapeCodeFactory, then the ANSI Escape-Code is prepended and an ANSI Reset-Code is appended to the according text being printed.- Parameters:
aEscapeCodeFactory- TheEscapeCodeFactoryto be used for determining ANSI escaping.- Returns:
- the column format metrics
-
setRowEscapeCodeFactory
Sets an ANSI Escape-Code factory for the row. In case an ANSI Escape-Code is set, then the ANSI Escape-Code is prepended and an ANSI Reset-Code is appended to the according text being printed.- Parameters:
aEscapeCodeFactory- TheEscapeCodeFactoryto be used for determining ANSI escaping. configuration.
-
getRowEscapeCodeFactory
EscapeCodeFactory getRowEscapeCodeFactory()Gets the ANSI Escape-Code factory for the row. In case an ANSI Escape-Code is set, then the ANSI Escape-Code is prepended and an ANSI Reset-Code is appended to the according text being printed.- Returns:
- The
EscapeCodeFactoryto be used for determining ANSI escaping.
-
toRowEscapeCode
Determines the ANSI Escape-Code by evaluating the provided TID: If anEscapeCodeFactoryhas been set viasetEscapeCodeFactory(EscapeCodeFactory)and the factory returns a value different to null, then this value is returned. Else the value returned bygetRowEscapeCode()is returned as fallback.- Parameters:
aIdentifier- The TID for which to lookup an Escape-Code.- Returns:
- The identified Escape-Code or null if none was identifiable.
-
setEscapeCode
Sets an ANSI Escape-Code for the header and the rows. In case an ANSI Escape-Code is set, then the ANSI Escape-Code is prepended and an ANSI Reset-Code is appended to the according text being printed.- Parameters:
aEscapeCode- TheStringto be used for ANSI escaping.
-
withHeaderEscapeCode
Sets an ANSI Escape-Code for the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern. In case an ANSI Escape-Code is set, then the ANSI Escape-Code is prepended and an ANSI Reset-Code is appended to the according text being printed.- Parameters:
aEscapeCode- TheStringto be used for ANSI escaping.- Returns:
- This
ColumnFormatMetricsinstance to continue configuration.
-
setHeaderEscapeCode
-
getHeaderEscapeCode
-
withRowEscapeCode
Sets an ANSI Escape-Code for the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern. The latest ANSI Escape-Code being set wins.- Parameters:
aEscapeCode- TheStringto be used for ANSI escaping.- Returns:
- This
ColumnFormatMetricsinstance to continue configuration.
-
setRowEscapeCode
Sets an ANSI Escape-Code for the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern. The latest ANSI Escape-Code being set wins.- Parameters:
aEscapeCode- TheStringto be used for ANSI escaping.
-
getRowEscapeCode
String getRowEscapeCode()Returns the ANSI Escape-Code for the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern. The latest ANSI Escape-Code being set wins.- Returns:
- The
Stringto be used for ANSI escaping.
-
withColumnWidth
- Specified by:
withColumnWidthin interfaceorg.refcodes.mixin.ColumnWidthAccessor.ColumnWidthBuilder<ColumnWidthMetrics>
-
withColumnWidthType
With column width type.- Specified by:
withColumnWidthTypein interfaceColumnWidthMetrics- Parameters:
aColumnWidthType- the column width type- Returns:
- the column width metrics
-
withHorizAlignTextMode
Sets the horizontal align text mode for the horizontal align text mode property.- Specified by:
withHorizAlignTextModein interfaceHorizAlignTextModeAccessor.HorizAlignTextModeBuilder<ColumnFormatMetrics>- Parameters:
aHorizAlignTextMode- The horizontal align text mode to be stored by the font style property.- Returns:
- The builder for applying multiple build operations.
-
setHorizAlignTextMode
Sets the horizontal align text mode for the horizontal align text mode property.- Specified by:
setHorizAlignTextModein interfaceHorizAlignTextModeAccessor.HorizAlignTextModeMutator- Parameters:
aHorizAlignTextMode- The horizontal align text mode to be stored by the font style property.
-
withHeaderHorizAlignTextMode
Sets an alignment mode for the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.- Parameters:
aHorizAlignTextMode- TheHorizAlignTextModeto be used for aligning the text.- Returns:
- This
TableBuilderinstance to continue configuration.
-
setHeaderHorizAlignTextMode
Sets an alignment mode for the header.- Parameters:
aHorizAlignTextMode- TheHorizAlignTextModeto be used for aligning the text.
-
getHeaderHorizAlignTextMode
HorizAlignTextMode getHeaderHorizAlignTextMode()Gets the alignment mode for the header.- Returns:
- The
HorizAlignTextModeto be used for aligning the text.
-
withRowHorizAlignTextMode
Sets an alignment mode for the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.- Parameters:
aHorizAlignTextMode- TheHorizAlignTextModeto be used for aligning the text.- Returns:
- This
TableBuilderinstance to continue configuration.
-
setRowHorizAlignTextMode
Sets an alignment mode for the row.- Parameters:
aHorizAlignTextMode- TheHorizAlignTextModeto be used for aligning the text.
-
getRowHorizAlignTextMode
HorizAlignTextMode getRowHorizAlignTextMode()Gets the alignment mode for the row.- Returns:
- The
HorizAlignTextModeto be used for aligning the text.
-
withMoreTextMode
Sets the more-text mode for the more-text mode property.- Specified by:
withMoreTextModein interfaceMoreTextModeAccessor.MoreTextModeBuilder<ColumnFormatMetrics>- Parameters:
aMoreTextMode- The more-text mode to be stored by the more-text mode property.- Returns:
- The builder for applying multiple build operations.
-
setMoreTextMode
Sets the more-text mode for the more-text mode property.- Specified by:
setMoreTextModein interfaceMoreTextModeAccessor.MoreTextModeMutator- Parameters:
aMoreTextMode- The more-text mode to be stored by the more-text mode property.
-
withHeaderMoreTextMode
Sets a more-text mode for the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.- Parameters:
aMoreTextMode- TheMoreTextModeto be used for truncating the text.- Returns:
- This
TableBuilderinstance to continue configuration.
-
setHeaderMoreTextMode
Sets a more-text mode for the header.- Parameters:
aMoreTextMode- TheMoreTextModeto be used for truncating the text.
-
getHeaderMoreTextMode
MoreTextMode getHeaderMoreTextMode()Gets the alignment mode for the header.- Returns:
- The
MoreTextModeto be used for truncating the text.
-
withRowMoreTextMode
Sets a more-text mode for the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.- Parameters:
aMoreTextMode- TheMoreTextModeto be used for truncating the text.- Returns:
- This
TableBuilderinstance to continue configuration.
-
setRowMoreTextMode
Sets a more-text mode for the row.- Parameters:
aMoreTextMode- TheMoreTextModeto be used for truncating the text.
-
getRowMoreTextMode
MoreTextMode getRowMoreTextMode()Gets the alignment mode for the row.- Returns:
- The
MoreTextModeto be used for truncating the text.
-
withTextFormatMode
Sets the text-format mode for the text-format mode property.- Specified by:
withTextFormatModein interfaceTextFormatModeAccessor.TextFormatModeBuilder<ColumnFormatMetrics>- Parameters:
aTextFormatMode- The text-format mode to be stored by the text-format mode property.- Returns:
- The builder for applying multiple build operations.
-
setTextFormatMode
Sets the text-format mode for the text-format mode property.- Specified by:
setTextFormatModein interfaceTextFormatModeAccessor.TextFormatModeMutator- Parameters:
aTextFormatMode- The text-format mode to be stored by the text-format mode property.
-
withSplitTextMode
Sets the split-text mode for the split-text mode property.- Specified by:
withSplitTextModein interfaceSplitTextModeAccessor.SplitTextModeBuilder<ColumnFormatMetrics>- Parameters:
aSplitTextMode- The split-text mode to be stored by the split-text mode property.- Returns:
- The builder for applying multiple build operations.
-
setSplitTextMode
Description copied from interface:SplitTextModeAccessor.SplitTextModeMutatorSets the split-text mode for the split-text mode property.- Specified by:
setSplitTextModein interfaceSplitTextModeAccessor.SplitTextModeMutator- Parameters:
aSplitTextMode- The split-text mode to be stored by the split-text mode property.
-
setHeaderSplitTextMode
Sets theSplitTextModefor the header.- Parameters:
aSplitTextMode- TheSplitTextModeto be set for the header;
-
getHeaderSplitTextMode
SplitTextMode getHeaderSplitTextMode()Returns theSplitTextModefor the header.- Returns:
- The
SplitTextModeto be set for the header;
-
withHeaderSplitTextMode
Sets theSplitTextModefor the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.- Parameters:
aSplitTextMode- TheSplitTextModeto be set for the header;- Returns:
- This
TableBuilderinstance to continue configuration.
-
setRowSplitTextMode
Sets theSplitTextModefor the row.- Parameters:
aSplitTextMode- TheSplitTextModeto be set for the row;
-
getRowSplitTextMode
SplitTextMode getRowSplitTextMode()Returns theSplitTextModefor the row.- Returns:
- The
SplitTextModeto be set for the row;
-
withRowSplitTextMode
Sets theSplitTextModefor the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.- Parameters:
aSplitTextMode- TheSplitTextModeto be set for the row;- Returns:
- This
TableBuilderinstance to continue configuration.
-
setHeaderTextFormatMode
Sets theTextFormatModefor the header.- Parameters:
aTextFormatMode- TheTextFormatModeto be set for the header;
-
getHeaderTextFormatMode
TextFormatMode getHeaderTextFormatMode()Returns theTextFormatModefor the header.- Returns:
- The
TextFormatModeto be set for the header;
-
withHeaderTextFormatMode
Sets theTextFormatModefor the header and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.- Parameters:
aTextFormatMode- TheTextFormatModeto be set for the header;- Returns:
- This
TableBuilderinstance to continue configuration.
-
setRowTextFormatMode
Sets theTextFormatModefor the row.- Parameters:
aTextFormatMode- TheTextFormatModeto be set for the row;
-
getRowTextFormatMode
TextFormatMode getRowTextFormatMode()Returns theTextFormatModefor the row.- Returns:
- The
TextFormatModeto be set for the row;
-
withRowTextFormatMode
Sets theTextFormatModefor the row and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.- Parameters:
aTextFormatMode- TheTextFormatModeto be set for the row;- Returns:
- This
TableBuilderinstance to continue configuration.
-
fromColumnFormatMetrics
From column format metrics.- Parameters:
aColumnFormatMetrics- the column format metrics
-