Interface EscapeCodeFactory
- All Superinterfaces:
LookupFactory<String,Object>
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
A
LookupFactory for creating ANSI Escape-Codes from an instance of a
given type.-
Nested Class Summary
Nested classes/interfaces inherited from interface LookupFactory
LookupFactory.ConfigurableLookupFactory<T,TID, OPTS> -
Method Summary
-
Method Details
-
create
-