Interface EscapeCodeFactory
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface
public interface EscapeCodeFactory
extends org.refcodes.factory.LookupFactory<String,Object>
A
LookupFactory for creating ANSI Escape-Codes from an instance of a
given type.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.factory.LookupFactory
org.refcodes.factory.LookupFactory.ConfigurableLookupFactory<T,TID, OPTS extends org.refcodes.factory.Options> -
Method Summary
-
Method Details
-
create
-