-
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface public interface EscapeCodeFactory extends org.refcodes.factory.LookupFactory<String,Object>
ALookupFactoryfor creating ANSI Escape-Codes from an instance of a given type.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description StringcreateInstance(Object aIdentifier)To instance.
-