- java.lang.Object
-
- org.refcodes.textual.RandomTextGenerartor
-
- All Implemented Interfaces:
Iterator<String>,org.refcodes.generator.Generator<String>,org.refcodes.mixin.CharSetAccessor,org.refcodes.mixin.CharSetAccessor.CharSetBuilder<RandomTextGenerartor>,org.refcodes.mixin.CharSetAccessor.CharSetMutator,org.refcodes.mixin.CharSetAccessor.CharSetProperty,org.refcodes.mixin.ColumnWidthAccessor,org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthBuilder<RandomTextGenerartor>,org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthMutator,org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthProperty
public class RandomTextGenerartor extends Object implements org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthBuilder<RandomTextGenerartor>, org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthProperty, org.refcodes.generator.Generator<String>, org.refcodes.mixin.CharSetAccessor.CharSetProperty, org.refcodes.mixin.CharSetAccessor.CharSetBuilder<RandomTextGenerartor>
Generates random text according to theRandomTextModeproperty and other settings.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.CharSetAccessor
org.refcodes.mixin.CharSetAccessor.CharSetBuilder<B extends org.refcodes.mixin.CharSetAccessor.CharSetBuilder<B>>, org.refcodes.mixin.CharSetAccessor.CharSetMutator, org.refcodes.mixin.CharSetAccessor.CharSetProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ColumnWidthAccessor
org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthBuilder<B extends org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthBuilder<B>>, org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthMutator, org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthProperty
-
-
Constructor Summary
Constructors Constructor Description RandomTextGenerartor()
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static StringasString(int aColumnWidth)Creates a random text with the given length consisting of the characters found inRandomTextMode.ALPHANUMERIC.static StringasString(int aColumnWidth, RandomTextMode aRandomTextMode)Creates a random text from the given parameters.char[]getCharSet()intgetColumnWidth()RandomTextModegetRandomTextMode()Retrieves the random text mode from the random text mode property.booleanhasNext()Stringnext()voidsetCharSet(char[] aCharSet)voidsetColumnWidth(int aColumnWidth)voidsetRandomTextMode(RandomTextMode aRandomTextMode)Sets the random text mode for the random text mode property.RandomTextGenerartorwithCharSet(char[] aCharSet)RandomTextGenerartorwithColumnWidth(int aColumnWidth)RandomTextGenerartorwithRandomTextMode(RandomTextMode aRandomTextMode)Sets the random text mode for the random text mode property.-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.mixin.ColumnWidthAccessor.ColumnWidthProperty
letColumnWidth
-
Methods inherited from interface java.util.Iterator
forEachRemaining, remove
-
-
-
-
Method Detail
-
withColumnWidth
public RandomTextGenerartor withColumnWidth(int aColumnWidth)
- Specified by:
withColumnWidthin interfaceorg.refcodes.mixin.ColumnWidthAccessor.ColumnWidthBuilder<RandomTextGenerartor>
-
setColumnWidth
public void setColumnWidth(int aColumnWidth)
- Specified by:
setColumnWidthin interfaceorg.refcodes.mixin.ColumnWidthAccessor.ColumnWidthMutator
-
getColumnWidth
public int getColumnWidth()
- Specified by:
getColumnWidthin interfaceorg.refcodes.mixin.ColumnWidthAccessor
-
hasNext
public boolean hasNext()
-
next
public String next()
-
getRandomTextMode
public RandomTextMode getRandomTextMode()
Retrieves the random text mode from the random text mode property.- Returns:
- The random text mode stored by the random text mode property.
-
setRandomTextMode
public void setRandomTextMode(RandomTextMode aRandomTextMode)
Sets the random text mode for the random text mode property.- Parameters:
aRandomTextMode- The random text mode to be stored by the random text mode property.
-
getCharSet
public char[] getCharSet()
- Specified by:
getCharSetin interfaceorg.refcodes.mixin.CharSetAccessor
-
setCharSet
public void setCharSet(char[] aCharSet)
- Specified by:
setCharSetin interfaceorg.refcodes.mixin.CharSetAccessor.CharSetMutator
-
withCharSet
public RandomTextGenerartor withCharSet(char[] aCharSet)
- Specified by:
withCharSetin interfaceorg.refcodes.mixin.CharSetAccessor.CharSetBuilder<RandomTextGenerartor>
-
withRandomTextMode
public RandomTextGenerartor withRandomTextMode(RandomTextMode aRandomTextMode)
Sets the random text mode for the random text mode property.- Parameters:
aRandomTextMode- The random text mode to be stored by the random text mode property.- Returns:
- The builder for applying multiple build operations.
-
asString
public static String asString(int aColumnWidth, RandomTextMode aRandomTextMode)
Creates a random text from the given parameters.- Parameters:
aColumnWidth- The length of the text to generate.aRandomTextMode- The chars to use for the random text.- Returns:
- The accordingly created random text.
-
asString
public static String asString(int aColumnWidth)
Creates a random text with the given length consisting of the characters found inRandomTextMode.ALPHANUMERIC.- Parameters:
aColumnWidth- The length of the text to generate.- Returns:
- The accordingly created random text.
-
-