Uses of Interface
org.refcodes.textual.EscapeCodeFactory
-
Uses of EscapeCodeFactory in org.refcodes.textual
Methods in org.refcodes.textual that return EscapeCodeFactoryModifier and TypeMethodDescriptionColumnFormatMetrics.getHeaderEscapeCodeFactory()Gets the ANSI Escape-Code factory for the header.ColumnFormatMetricsImpl.getHeaderEscapeCodeFactory()Gets the ANSI Escape-Code factory for the header.ColumnFormatMetrics.getRowEscapeCodeFactory()Gets the ANSI Escape-Code factory for the row.ColumnFormatMetricsImpl.getRowEscapeCodeFactory()Gets the ANSI Escape-Code factory for the row.Methods in org.refcodes.textual with parameters of type EscapeCodeFactoryModifier and TypeMethodDescriptiondefault voidColumnFormatMetrics.setEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows.voidColumnFormatMetrics.setHeaderEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header.voidColumnFormatMetricsImpl.setHeaderEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header.voidColumnFormatMetrics.setRowEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the row.voidColumnFormatMetricsImpl.setRowEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the row.default ColumnFormatMetricsColumnFormatMetrics.withEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnSetupMetricsColumnSetupMetrics.withEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withHeaderEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnSetupMetricsColumnSetupMetrics.withHeaderEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the header and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnFormatMetricsColumnFormatMetrics.withRowEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the row and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.default ColumnSetupMetricsColumnSetupMetrics.withRowEscapeCodeFactory(EscapeCodeFactory aEscapeCodeFactory) Sets an ANSI Escape-Code factory for the row and the rows and returns thisColumnFormatMetricsinstance as of the Builder-Pattern.