Uses of Enum Class
org.refcodes.textual.RandomTextMode
-
Uses of RandomTextMode in org.refcodes.textual
Methods in org.refcodes.textual that return RandomTextModeModifier and TypeMethodDescriptionRandomTextGenerartor.getRandomTextMode()Retrieves the random text mode from the random text mode property.static RandomTextModeReturns the enum constant of this class with the specified name.static RandomTextMode[]RandomTextMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.textual with parameters of type RandomTextModeModifier and TypeMethodDescriptionstatic StringRandomTextGenerartor.asString(int aColumnWidth, RandomTextMode aRandomTextMode) Creates a random text from the given parameters.voidRandomTextGenerartor.setRandomTextMode(RandomTextMode aRandomTextMode) Sets the random text mode for the random text mode property.RandomTextGenerartor.withRandomTextMode(RandomTextMode aRandomTextMode) Sets the random text mode for the random text mode property.