Uses of Class
org.refcodes.textual.RandomTextMode
-
-
Uses of RandomTextMode in org.refcodes.textual
Methods in org.refcodes.textual that return RandomTextMode Modifier and Type Method Description RandomTextModeRandomTextGenerartor. getRandomTextMode()Retrieves the random text mode from the random text mode property.static RandomTextModeRandomTextMode. valueOf(String name)Returns the enum constant of this type with the specified name.static RandomTextMode[]RandomTextMode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.textual with parameters of type RandomTextMode Modifier and Type Method Description static StringRandomTextGenerartor. asString(int aColumnWidth, RandomTextMode aRandomTextMode)Creates a random text from the given parameters.voidRandomTextGenerartor. setRandomTextMode(RandomTextMode aRandomTextMode)Sets the random text mode for the random text mode property.RandomTextGenerartorRandomTextGenerartor. withRandomTextMode(RandomTextMode aRandomTextMode)Sets the random text mode for the random text mode property.
-