Uses of Interface
org.refcodes.textual.TextBoxGrid
-
Uses of TextBoxGrid in org.refcodes.textual
Subinterfaces of TextBoxGrid in org.refcodes.textualModifier and TypeInterfaceDescriptionstatic interfaceAn incarnation of theBoxGrid.BoxGridPropertyusing grid elements of typeCharacter.Classes in org.refcodes.textual that implement TextBoxGridMethods in org.refcodes.textual that return TextBoxGridModifier and TypeMethodDescriptionTableStyle.getBody()Returns the table body's characters.TableStyle.getHeader()Returns the table header's characters.TableStyle.getTail()Returns the table tail's characters.TextBorderBuilder.getTextBoxGrid()Gets the currently setTextBoxGridbeing used.TextBoxGridAccessor.getTextBoxGrid()Gets the currently setTextBoxGridbeing used.TextBoxStyle.getTextBoxGrid()Returns theTextBoxStyle's characters.default TextBoxGridTextBoxGridAccessor.TextBoxGridProperty.letTextBoxGrid(TextBoxGrid aTextBoxGrid) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTextBoxGrid(setter) as ofTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid)and returns the very same value (getter).Methods in org.refcodes.textual with parameters of type TextBoxGridModifier and TypeMethodDescriptiondefault TextBoxGridTextBoxGridAccessor.TextBoxGridProperty.letTextBoxGrid(TextBoxGrid aTextBoxGrid) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTextBoxGrid(setter) as ofTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid)and returns the very same value (getter).voidTextBorderBuilder.setTextBoxGrid(TextBoxGrid aTextBoxGrid) Sets theTextBoxGridto be used.voidTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid aTextBoxGrid) Sets theTextBoxGridto be used.TextBorderBuilder.withTextBoxGrid(TextBoxGrid aTextBoxGrid) Sets the rowsTextBoxGridto use returns this builder as of the Builder-Pattern.TextBoxGridAccessor.TextBoxGridBuilder.withTextBoxGrid(TextBoxGrid aTextBoxGrid) Sets the rowsTextBoxGridto use returns this builder as of the Builder-Pattern.