Uses of Interface
org.refcodes.textual.TextBoxGrid
-
-
Uses of TextBoxGrid in org.refcodes.textual
Subinterfaces of TextBoxGrid in org.refcodes.textual Modifier and Type Interface Description static interfaceTextBoxGrid.TextBoxGridPropertyAn incarnation of theBoxGrid.BoxGridPropertyusing grid elements of typeCharacter.Classes in org.refcodes.textual that implement TextBoxGrid Modifier and Type Class Description classTextBoxGridImplImplementation of theTextBoxGridinterface.Methods in org.refcodes.textual that return TextBoxGrid Modifier and Type Method Description TextBoxGridTableStyle. getBody()Returns the table body's characters.TextBoxGridTableStyle. getHeader()Returns the table header's characters.TextBoxGridTableStyle. getTail()Returns the table tail's characters.TextBoxGridTextBorderBuilder. getTextBoxGrid()Gets the currently setTextBoxGridbeing used.TextBoxGridTextBoxGridAccessor. getTextBoxGrid()Gets the currently setTextBoxGridbeing used.TextBoxGridTextBoxStyle. getTextBoxGrid()Returns theTextBoxStyle's characters.default TextBoxGridTextBoxGridAccessor.TextBoxGridProperty. letTextBoxGrid(TextBoxGrid aTextBoxGrid)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTextBoxGrid(setter) as ofTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid)and returns the very same value (getter).Methods in org.refcodes.textual with parameters of type TextBoxGrid Modifier and Type Method Description default TextBoxGridTextBoxGridAccessor.TextBoxGridProperty. letTextBoxGrid(TextBoxGrid aTextBoxGrid)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTextBoxGrid(setter) as ofTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid)and returns the very same value (getter).voidTextBorderBuilder. setTextBoxGrid(TextBoxGrid aTextBoxGrid)Sets theTextBoxGridto be used.voidTextBoxGridAccessor.TextBoxGridMutator. setTextBoxGrid(TextBoxGrid aTextBoxGrid)Sets theTextBoxGridto be used.TextBorderBuilderTextBorderBuilder. withTextBoxGrid(TextBoxGrid aTextBoxGrid)Sets the rowsTextBoxGridto use returns this builder as of the Builder-Pattern.BTextBoxGridAccessor.TextBoxGridBuilder. withTextBoxGrid(TextBoxGrid aTextBoxGrid)Sets the rowsTextBoxGridto use returns this builder as of the Builder-Pattern.
-