Uses of Enum Class
org.refcodes.textual.TextBoxStyle
-
Uses of TextBoxStyle in org.refcodes.textual
Fields in org.refcodes.textual declared as TextBoxStyleModifier and TypeFieldDescriptionstatic final TextBoxStyleTextBoxStyle.ASCII_TEXT_BOX_STYLEStyle displayed for sure when being under test (e.g.static final TextBoxStyleTextBoxStyle.UNICODE_TEXT_BOX_STYLEStyle supported Unicode capable terminals (when not being under test).static final TextBoxStyleTextBoxStyle.WINDOWS_TEXT_BOX_STYLEStyle displayed for sure when being on a Windows machine.Methods in org.refcodes.textual that return TextBoxStyleModifier and TypeMethodDescriptionstatic TextBoxStyleReturns the enum constant of this class with the specified name.static TextBoxStyle[]TextBoxStyle.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.textual with parameters of type TextBoxStyleModifier and TypeMethodDescriptiondefault TextBoxGridTextBoxGridAccessor.TextBoxGridProperty.letTextBoxGrid(TextBoxStyle aTextBoxStyle) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTextBoxGrid(setter) as ofTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxGrid)and returns the very same value (getter).default voidTextBoxGridAccessor.TextBoxGridMutator.setTextBoxGrid(TextBoxStyle aTextBoxStyle) Sets theTextBoxGridto be used.voidTextBorderBuilder.setTextBoxStyle(TextBoxStyle aTextBoxStyle) Convenience method forTextBorderBuilder.setTextBoxGrid(TextBoxGrid)to set theTextBoxGridfrom aTextBoxStylevalueTextBorderBuilder.withTextBoxGrid(TextBoxStyle aTextBoxStyle) Sets the rowsTextBoxGridto use returns this builder as of the Builder-Pattern.default BTextBoxGridAccessor.TextBoxGridBuilder.withTextBoxGrid(TextBoxStyle aTextBoxStyle) Sets the rowsTextBoxGridto use returns this builder as of the Builder-Pattern.TextBorderBuilder.withTextBoxStyle(TextBoxStyle aTextBoxStyle) Convenience method forTextBorderBuilder.withTextBoxGrid(TextBoxGrid)to set theTextBoxGridfrom aTextBoxStylevalue