Uses of Class
org.refcodes.textual.TextBoxStyle
-
-
Uses of TextBoxStyle in org.refcodes.textual
Fields in org.refcodes.textual declared as TextBoxStyle Modifier and Type Field Description static TextBoxStyleTextBoxStyle. OTHER_TEXT_BOX_STYLEStyle displayed for sure when being under test (e.g.static TextBoxStyleTextBoxStyle. UNICODE_TEXT_BOX_STYLEStyle supported Unicode capable terminals (when not being under test).static TextBoxStyleTextBoxStyle. WINDOWS_TEXT_BOX_STYLEStyle displayed for sure when being on a Windows machine.Methods in org.refcodes.textual that return TextBoxStyle Modifier and Type Method Description static TextBoxStyleTextBoxStyle. toRuntimeTextBoxStyle()Depending on the runtime environment (Windows, Linux, JUnit) we prefer different text box styles as depending on the runtime environment not all characters used by the various text box styles may be available.static TextBoxStyleTextBoxStyle. toTableStyle(String aValue)Retrieves the best fittingTextBoxStylefor the given value by ignoring the characters' case as well as all "-" and "_" characters in the provided value as well as in the enumeration's name..static TextBoxStyleTextBoxStyle. valueOf(String name)Returns the enum constant of this type with the specified name.static TextBoxStyle[]TextBoxStyle. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.textual with parameters of type TextBoxStyle Modifier and Type Method Description voidTextBorderBuilder. setTextBoxStyle(TextBoxStyle aTextBoxStyle)Convenience method forTextBorderBuilder.setTextBoxGrid(TextBoxGrid)to set theTextBoxGridfrom aTextBoxStylevalueTextBorderBuilderTextBorderBuilder. withTextBoxStyle(TextBoxStyle aTextBoxStyle)Convenience method forTextBorderBuilder.withTextBoxGrid(TextBoxGrid)to set theTextBoxGridfrom aTextBoxStylevalue
-